Package: Compositional
Type: Package
Title: Compositional Data Analysis
Version: 8.2
Date: 2026-05-22
Authors@R: c(person("Michail", "Tsagris", role = c("aut", "cre"), email = "mtsagris@uoc.gr"),
           person("Giorgos", "Athineou", role = "aut", email = "gioathineou@gmail.com"),
           person("Abdulaziz", "Alenazi", role = "ctb", email = "a.alenazi@nbu.edu.sa"),
		       person("Christos", "Adam", role = "ctb", email = "pada4m4@gmail.com"))
Author: Michail Tsagris [aut, cre],
  Giorgos Athineou [aut],
  Abdulaziz Alenazi [ctb],
  Christos Adam [ctb]
Maintainer: Michail Tsagris <mtsagris@uoc.gr>
Depends: R (>= 4.0)
Imports: bigstatsr, cluster, emplik, glmnet, graphics, grDevices,
        quantreg, MASS, Matrix, mda, minpack.lm, mixture, nnet, osqp,
        quadprog, parallel, rangen, Rfast, Rfast2, rgl, Rnanoflann, sn,
        stats
Suggests: bigparallelr, codalm, FlexDir
Description: Regression, classification, contour plots, hypothesis testing and fitting of distributions for compositional data are some of the functions included. We further include functions for percentages (or proportions).
             The standard textbook for such data is John Aitchison's (1986) "The statistical analysis of compositional data". Relevant papers include:
			       a) Tsagris M.T., Preston S. and Wood A.T.A. (2011). "A data--based power transformation for compositional data". Fourth International International Workshop on Compositional Data Analysis. <doi:10.48550/arXiv.1106.1451>.
			       b) Tsagris M. (2014). "The k--NN algorithm for compositional data: a revised approach with and without zero values present". Journal of Data Science, 12(3): 519--534. <doi:10.6339/JDS.201407_12(3).0008>.
			       c) Tsagris M. (2015). "A novel, divergence based, regression for compositional data". Proceedings of the 28th Panhellenic Statistics Conference, 15-18 April 2015, Athens, Greece, 430--444. <doi:10.48550/arXiv.1511.07600>.
			       d) Tsagris M. (2015). "Regression analysis with compositional data containing zero values". Chilean Journal of Statistics, 6(2): 47--57. <https://soche.cl/chjs/volumes/06/02/Tsagris(2015).pdf>.
			       e) Tsagris M., Preston S. and Wood A.T.A. (2016). "Improved supervised classification for compositional data using the alpha-transformation". Journal of Classification, 33(2): 243--261. <doi:10.1007/s00357-016-9207-5>. 
			       f) Tsagris M., Preston S. and Wood A.T.A. (2017). "Nonparametric hypothesis testing for equality of means on the simplex". Journal of Statistical Computation and Simulation, 87(2): 406--422. <doi:10.1080/00949655.2016.1216554>. 
			       g) Tsagris M. and Stewart C. (2018). "A Dirichlet regression model for compositional data with zeros". Lobachevskii Journal of Mathematics, 39(3): 398--412. <doi:10.1134/S1995080218030198>. 
			       h) Alenazi A. (2019). "Regression for compositional data with compositional data as predictor variables with or without zero values". Journal of Data Science, 17(1): 219--238. <doi:10.6339/JDS.201901_17(1).0010>. 
		         i) Tsagris M. and Stewart C. (2020). "A folded model for compositional data analysis". Australian and New Zealand Journal of Statistics, 62(2): 249--277. <doi:10.1111/anzs.12289>. 
		         j) Alenazi A.A. (2022). "f--divergence regression models for compositional data". Pakistan Journal of Statistics and Operation Research, 18(4): 867--882. <doi:10.18187/pjsor.v18i4.3969>.
		         k) Tsagris M. and Stewart C. (2022). "A Review of Flexible Transformations for Modeling Compositional Data". In Advances and Innovations in Statistics and Data Science, pp. 225--234. <doi:10.1007/978-3-031-08329-7_10>.
		         l) Alenazi A. (2023). "A review of compositional data analysis and recent advances". Communications in Statistics--Theory and Methods, 52(16): 5535--5567. <doi:10.1080/03610926.2021.2014890>.
			       m) Tsagris M., Alenazi A. and Stewart C. (2023). "Flexible non--parametric regression models for compositional response data with zeros". Statistics and Computing, 33(106). <doi:10.1007/s11222-023-10277-5>. 
			       n) Tsagris. M. (2025). "Constrained least squares simplicial--simplicial regression". Statistics and Computing, 35(27). <doi:10.1007/s11222-024-10560-z>.
			       o) Sevinc V. and Tsagris. M. (2026). "Energy Based Equality of Distributions Testing for Compositional Data". Communications in Statistics--Simulation and Computation. <doi:10.1080/03610918.2026.2636167>.
			       p) Tsagris M. and Alzeley O. (2025). "Scalable approximation of the transformation--free linear simplicial--simplicial regression via constrained iterative reweighted least squares". <doi:10.48550/arXiv.2511.13296>.
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2026-05-22 15:02:57 UTC; mtsag
Repository: CRAN
Date/Publication: 2026-05-23 05:13:05 UTC
Built: R 4.6.0; ; 2026-05-23 10:07:08 UTC; unix
